# GATE Slave

The GATE Slave is a module that allows to run anything you want in a Java GATE process from Python and interchange documents between Python and Java.

One possible use of this is to run an existing GATE pipeline on a `gatenlp` Python document. 